# Copyright 2015 Shannon Lucas
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License.  You may obtain a copy
# of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
# License for the specific language governing permissions and limitations under
# the License.

"""Provides the exception hierarchy for the ordered text parser."""


class ParserError(Exception):
    """Generic root exception for the parser."""


class ParseCommandError(ParserError):
    """Raised when a parse command is unable to correctly parse the text it
     expected."""


class MinimumCountError(ParserError):
    """Raised when an element did not occur the minimum number of times."""

    __MESSAGE = "{0} expected: {1}, found: {2}"

    __slots__ = ("expected", "actual")

    def __init__(self, name, expected=None, actual=None):
        """Creates a new MinimumCountError

        :param str name: the name of the command that failed.
        :param int expected: the number of occurrences expected.
        :param int actual: the number of occurrences found.
        """
        self.expected = expected
        self.actual = actual
        message = name if expected is None else \
            MinimumCountError.__MESSAGE.format(name, expected, actual)

        super().__init__(message)
