# Copyright 2015 Shannon Lucas
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License.  You may obtain a copy
# of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
# License for the specific language governing permissions and limitations under
# the License.

from setuptools import setup
from codecs import open
from os import path

base_dir = path.abspath(path.dirname(__file__))

about = {}
with open(path.join(base_dir, "ordtext", "__about__.py")) as f:
    exec(f.read(), about)

# Get the long description from the relevant file
with open(path.join(base_dir, "DESCRIPTION.rst"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name=about["__title__"],
    version=about["__version__"],
    description=about["__summary__"],
    long_description=long_description,
    license=about["__license__"],
    url=about["__uri__"],
    author=about["__author__"],
    author_email=about["__email__"],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries",
        "Topic :: Text Processing",
        "Topic :: Text Processing :: General",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3 :: Only",
        "Operating System :: OS Independent"
    ],
    keywords="text parser parsing",
    packages=["ordtext"],
    install_requires=[],
    extras_require={
        "dev": ["check-manifest"],
        "test": ["coverage", "pytest"],
    },
)
